/* 
 * 
 * Home Health Grouper Software
 * 
 * Center for Medicare and Medicaid Services (CMS)
 * 
 * All code is provided as is.
 * 
 */
package gov.cms.hh.grouper;

import gov.cms.hh.data.files.TableNames_EN;
import gov.cms.hh.reference.objects.ClinicalGroupObject;
import gov.cms.hh.reference.objects.ComorbidityGroupObject;
import gov.cms.hh.reference.objects.ComorbidityInteractionObject;
import gov.cms.hh.reference.objects.DiagnosisObject;
import gov.cms.hh.reference.objects.DiagnosisSubchapterObject;
import gov.cms.hh.reference.objects.HippsValueObject;
import gov.cms.hh.reference.objects.OasisRespondObject;
import gov.cms.hh.reference.objects.ReturnCodeObject;
import java.util.Map;
import java.util.TreeMap;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author CMS
 */
public class DataManager implements DataManagerIF {

    private static final Logger LOG = Logger.getLogger(DataManager.class.getName());

    /**
     *
     * @param rtBasePath
     * @param loadDescriptions
     */
    public DataManager(String rtBasePath, boolean loadDescriptions) {
        this.rtBasePath = rtBasePath;
        this.loadDescriptions = loadDescriptions;
        loadOtherData();
    }

    /**
     *
     * @param rtBasePath
     */
    public DataManager(String rtBasePath) {
        // ctor chain
        this(rtBasePath, false);
    }

    // load DX RT tables here
    private void loadDxData() {

        // Diagnoses
        String inpFile = rtBasePath + "/" + TableNames_EN.Diagnoses.getFileName();
        DataContainerIF<DiagnosisObject> diagnoses
                = new DataContainer(inpFile, 0, DiagnosisObject.class, loadDescriptions);
        dataMap.put(TableNames_EN.Diagnoses, diagnoses);
        
        LOG.log(Level.INFO, "Grouper Data Manager instantiated: DX RT path: {0}, Descriptions loaded: {1}", new Object[]{rtBasePath, loadDescriptions});
        
    }
    
    // load all Other RT tables here
    private void loadOtherData() {

        dataMap = new TreeMap();
        
        // Clinical Group RT
        String inpFile = rtBasePath + "/" + TableNames_EN.Clinical_Groups.getFileName();
        DataContainerIF<ClinicalGroupObject> clinicalGroups
                = new DataContainer(inpFile, 0, ClinicalGroupObject.class, loadDescriptions);
        dataMap.put(TableNames_EN.Clinical_Groups, clinicalGroups);

        // Comorbidity Group RT
        inpFile = rtBasePath + "/" + TableNames_EN.Comorbidity_Groups.getFileName();
        DataContainerIF<ComorbidityGroupObject> comorbidityGroups
                = new DataContainer(inpFile, 0, ComorbidityGroupObject.class, loadDescriptions);
        dataMap.put(TableNames_EN.Comorbidity_Groups, comorbidityGroups);

        // Comorbidity Interactions RT
        inpFile = rtBasePath + "/" + TableNames_EN.Comorbidity_Interactions.getFileName();
        DataContainerIF<ComorbidityInteractionObject> comorbidityInteractions
                = new DataContainer(inpFile, 0, ComorbidityInteractionObject.class, loadDescriptions);
        dataMap.put(TableNames_EN.Comorbidity_Interactions, comorbidityInteractions);

        // Diagnosis Subchapter RT
        inpFile = rtBasePath + "/" + TableNames_EN.Diagnosis_Subchapters.getFileName();
        DataContainerIF<DiagnosisSubchapterObject> diagnosisSubchapters
                = new DataContainer(inpFile, 0, DiagnosisSubchapterObject.class, loadDescriptions);
        dataMap.put(TableNames_EN.Diagnosis_Subchapters, diagnosisSubchapters);

        // HIPPS Structure RT
        inpFile = rtBasePath + "/" + TableNames_EN.HIPPS_Structure.getFileName();
        DataContainerIF<HippsValueObject> hippsValues
                = new DataContainer(inpFile, HippsValueObject.class, true); // Grouper result (HIPPS code) descriptions are not disableable
        dataMap.put(TableNames_EN.HIPPS_Structure, hippsValues);

        // OASIS Responses RT
        inpFile = rtBasePath + "/" + TableNames_EN.OASIS_Responses.getFileName();
        DataContainerIF<OasisRespondObject> oasisResponces
                = new DataContainer(inpFile, OasisRespondObject.class, loadDescriptions);
        dataMap.put(TableNames_EN.OASIS_Responses, oasisResponces);

        // Return Codes RT
        inpFile = rtBasePath + "/" + TableNames_EN.Return_Codes.getFileName();
        DataContainerIF<ReturnCodeObject> returnCodes
                = new DataContainer(inpFile, 0, ReturnCodeObject.class, true); // GRC descriptions are not disableable
        dataMap.put(TableNames_EN.Return_Codes, returnCodes);

//        LOG.log(Level.INFO, "Grouper Data Manager instantiated: Other RT path: {0}, Descriptions loaded: {1}", new Object[]{rtBasePath, loadDescriptions});
        
    }

    private Map<TableNames_EN, DataContainerIF> dataMap;
    private String rtBasePath;
    private boolean loadDescriptions;

    /**
     * @return the dataMap
     */
    @Override
    public Map<TableNames_EN, DataContainerIF> getDataMap() {
        // load all rots via lazy initialization
        if (dataMap.get(TableNames_EN.Diagnoses) == null) {
            loadDxData();
        }
        return dataMap;
    }

    /**
     * @param dataMap the dataMap to set
     */
    @Override
    public void setDataMap(Map<TableNames_EN, DataContainerIF> dataMap) {
        this.dataMap = dataMap;
    }
}
